@@ -14,7 +14,7 @@ import os
 # %matplotlib inline
 
 
-def analyze_rois(file, room_layout, output_dir, trial_type):
+def analyze_rois(file, room_layout, output_dir, trial_type, span=''):
 
     if output_dir.endswith('/') == False:
 
@@ -68,17 +68,17 @@ def analyze_rois(file, room_layout, output_dir, trial_type):
     for trial, trial_name in zip(trials, trials_names):
 
         time = trial['time']
-        velocity = trial['velocity_loess']
+        velocity = trial['velocity_loess' + span]
 
         if trial_type == 'with_owner':
 
-            x_cat = trial['x_cat_loess']
-            y_cat = trial['y_cat_loess']
+            x_cat = trial['x_cat_loess' + span]
+            y_cat = trial['y_cat_loess' + span]
 
         elif trial_type == 'cat_alone':
 
-            x_cat = trial['x_loess']
-            y_cat = trial['y_loess']
+            x_cat = trial['x_loess' + span]
+            y_cat = trial['y_loess' + span]
 
         # Calculate and plot rois
 
@@ -208,7 +208,7 @@ def analyze_rois(file, room_layout, output_dir, trial_type):
     if trial_type == 'with_owner':
 
         sort_by_trial = {
-            'No treatment': 0,
+            'No Treatment': 0,
             'First Saline': 1,
             'First Urine': 3,
             'Second Saline': 4,
@@ -218,11 +218,11 @@ def analyze_rois(file, room_layout, output_dir, trial_type):
     elif trial_type == 'cat_alone':
 
         sort_by_trial = {
-            'Cat alone (1)': 0,
-            'Cat alone (2)': 1,
-            'Cat alone (3)': 3,
-            'Cat alone (4)': 4,
-            'Cat alone (5)': 5
+            'Cat Alone (1)': 0,
+            'Cat Alone (2)': 1,
+            'Cat Alone (3)': 3,
+            'Cat Alone (4)': 4,
+            'Cat Alone (5)': 5
         }
 
     combined_csv = combined_csv.iloc[combined_csv['trial'].map(
